@@ -30,6 +30,11 @@ class Connect:
             self.username = username
             self.auth = HTTPBasicAuth(username, passwd)
 
+            if self.open_port(ipaddr, 8443) is False:
+                raise Exception(f"Connection Error: {ipaddr}:8443 not reachable or open. Is this Unity Connection?")
+            if self.get("cluster") is False:
+                raise Exception(f"Connection Error: AXL request not valid. Improper credentials?")
+
             try:
                 self.version = self.get("version")[0]['version']
             except Exception as err:
